@@ -50,7 +50,7 @@
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
 #include <libanjuta/interfaces/ianjuta-message-manager.h>
 
-#include <libgnomevfs/gnome-vfs.h>
+#include <gio/gio.h>
 
 /* Contants defintion
  *---------------------------------------------------------------------------*/
@@ -189,10 +189,10 @@ hide_program_counter_in_editor(DebugManagerPlugin *self)
 }
 
 static void
-set_program_counter(DebugManagerPlugin *self, const gchar* file, guint line, gulong address)
+set_program_counter(DebugManagerPlugin *self, const gchar* filename, guint line, gulong address)
 {
 	IAnjutaDocumentManager *docman = NULL;
-	gchar *file_uri;
+	GFile* file;
 
 	/* Remove previous marker */
 	hide_program_counter_in_editor (self);
@@ -203,15 +203,15 @@ set_program_counter(DebugManagerPlugin *self, const gchar* file, guint line, gul
 	}
 	self->pc_address = address;
 
-	if (file != NULL)
+	if (filename != NULL)
 	{
+		file = g_file_new_for_path (filename);
 		docman = anjuta_shell_get_interface (ANJUTA_PLUGIN (self)->shell, IAnjutaDocumentManager, NULL);
-		file_uri = gnome_vfs_get_uri_from_local_path(file);
 		if (docman)
 		{
 			IAnjutaEditor* editor;
 		
-			editor = ianjuta_document_manager_goto_uri_line(docman, file_uri, line, NULL);
+			editor = ianjuta_document_manager_goto_file_line(docman, file, line, NULL);
 		
 			if (editor != NULL)
 			{
@@ -221,7 +221,7 @@ set_program_counter(DebugManagerPlugin *self, const gchar* file, guint line, gul
 				show_program_counter_in_editor (self);
 			}
 		}		
-		g_free (file_uri);
+		g_object_unref (file);
 	}
 }
 
@@ -368,7 +368,7 @@ dma_plugin_debugger_started (DebugManagerPlugin *this)
 	GtkAction *action;
 	AnjutaStatus* status;
 
-	DEBUG_PRINT ("DMA: dma_plugin_debugger_started");
+	DEBUG_PRINT ("%s", "DMA: dma_plugin_debugger_started");
 	
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (this)->shell, NULL);
 	
@@ -394,17 +394,8 @@ dma_plugin_program_loaded (DebugManagerPlugin *this)
 	AnjutaUI *ui;
 	AnjutaStatus* status;
 
-	DEBUG_PRINT ("DMA: dma_plugin_program_loaded");
+	DEBUG_PRINT ("%s", "DMA: dma_plugin_program_loaded");
 	
-	if (this->sharedlibs == NULL)
-	{
-		this->sharedlibs = sharedlibs_new (this);
-	}
-	if (this->signals == NULL)
-	{
-		this->signals = signals_new (this);
-	}
-
 	/* Update ui */
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (this)->shell, NULL);
 	gtk_action_group_set_sensitive (this->loaded_group, TRUE);
@@ -423,7 +414,7 @@ dma_plugin_program_running (DebugManagerPlugin *this)
 	AnjutaUI *ui;
 	AnjutaStatus* status;
 
-	DEBUG_PRINT ("DMA: dma_plugin_program_running");
+	DEBUG_PRINT ("%s", "DMA: dma_plugin_program_running");
 	
 	/* Update ui */
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (this)->shell, NULL);
@@ -445,7 +436,7 @@ dma_plugin_program_stopped (DebugManagerPlugin *this)
 	AnjutaUI *ui;
 	AnjutaStatus* status;
 	
-	DEBUG_PRINT ("DMA: dma_plugin_program_broken");
+	DEBUG_PRINT ("%s", "DMA: dma_plugin_program_broken");
 	
 	/* Update ui */
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (this)->shell, NULL);
@@ -474,19 +465,8 @@ dma_plugin_program_unload (DebugManagerPlugin *this)
 	AnjutaUI *ui;
 	AnjutaStatus* status;
 
-	DEBUG_PRINT ("DMA: dma_plugin_program_unload");
+	DEBUG_PRINT ("%s", "DMA: dma_plugin_program_unload");
 	
-	if (this->sharedlibs != NULL)
-	{
-		sharedlibs_free (this->sharedlibs);
-		this->sharedlibs = NULL;
-	}
-	if (this->signals == NULL)
-	{
-		signals_free (this->signals);
-		this->signals = NULL;
-	}
-
 	/* Update ui */
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (this)->shell, NULL);
 	gtk_action_group_set_visible (this->start_group, TRUE);
@@ -511,7 +491,7 @@ dma_plugin_debugger_stopped (DebugManagerPlugin *self, GError *err)
 	GtkAction *action;
 	AnjutaStatus* state;
 
-	DEBUG_PRINT ("DMA: dma_plugin_debugger_stopped");
+	DEBUG_PRINT ("%s", "DMA: dma_plugin_debugger_stopped");
 
 	dma_plugin_program_unload (self);
 	
@@ -560,17 +540,18 @@ dma_plugin_signal_received (DebugManagerPlugin *self, const gchar *name, const g
 /* Called when the user want to go to another location */
 
 static void
-dma_plugin_location_changed (DebugManagerPlugin *self, gulong address, const gchar* uri, guint line)
+dma_plugin_location_changed (DebugManagerPlugin *self, gulong address, const gchar *uri, guint line)
 {
 	/* Go to location in editor */
 	if (uri != NULL)
 	{
 		IAnjutaDocumentManager *docman;
-
         docman = anjuta_shell_get_interface (ANJUTA_PLUGIN(self)->shell, IAnjutaDocumentManager, NULL);
         if (docman)
         {
-			ianjuta_document_manager_goto_uri_line (docman, uri, line, NULL);
+			GFile *file = g_file_new_for_uri (uri);
+			ianjuta_document_manager_goto_file_line (docman, file, line, NULL);
+			g_object_unref (file);
         }
 	}
 }
@@ -582,20 +563,7 @@ static void
 on_start_debug_activate (GtkAction* action, DebugManagerPlugin* this)
 {
 	enable_log_view (this, TRUE);
-	if (dma_run_target (this->start))
-	{
-		GtkAction *action;
-		action = gtk_action_group_get_action (this->start_group, "ActionDebuggerRestartTarget");
-		gtk_action_set_sensitive (action, TRUE);
-	}
-
-}
-
-static void
-on_restart_debug_activate (GtkAction* action, DebugManagerPlugin* this)
-{
-	enable_log_view (this, TRUE);
-	dma_rerun_target (this->start);
+	dma_run_target (this->start, NULL);
 }
 
 static void
@@ -605,6 +573,14 @@ on_attach_to_project_action_activate (GtkAction* action, DebugManagerPlugin* thi
 	dma_attach_to_process (this->start);
 }
 
+static void
+on_start_remote_debug_action_activate (GtkAction* action, DebugManagerPlugin* this)
+{
+	/* Returns true if user clicked "Connect" */
+	enable_log_view (this, TRUE);
+	dma_run_remote_target (this->start, NULL, NULL);
+}
+
 static void
 on_debugger_stop_activate (GtkAction* action, DebugManagerPlugin* plugin)
 {
@@ -684,23 +660,23 @@ on_run_to_cursor_action_activate (GtkAction* action, DebugManagerPlugin* plugin)
 		else
 		{
 			IAnjutaEditor *editor;
-			gchar *uri;
-			gchar *file;
+			GFile* file;
+			gchar *filename;
 			gint line;
 
 			editor = dma_get_current_editor (ANJUTA_PLUGIN (plugin));
 			if (editor == NULL)
 				return;
-			uri = ianjuta_file_get_uri (IANJUTA_FILE (editor), NULL);
-			if (uri == NULL)
+			file = ianjuta_file_get_file (IANJUTA_FILE (editor), NULL);
+			if (file == NULL)
 				return;
 	
-			file = gnome_vfs_get_local_path_from_uri (uri);
+			filename = g_file_get_path (file);
 	
 			line = ianjuta_editor_get_lineno (editor, NULL);
-			dma_queue_run_to (plugin->queue, file, line);
-			g_free (uri);
-			g_free (file);
+			dma_queue_run_to (plugin->queue, filename, line);
+			g_free (filename);
+			g_object_unref (file);
 		}
 	}
 }
@@ -846,27 +822,27 @@ static GtkActionEntry actions_start[] =
 	{
 		"ActionDebuggerRunTarget",
 		NULL,
-		N_("Run Target..."),
+		N_("_Debug Program"),
 		"<shift>F12",
-		N_("load and start the target for debugging"),
+		N_("Start debugger and load the program"),
 		G_CALLBACK (on_start_debug_activate)
 	},
-	{
-		"ActionDebuggerRestartTarget",
-		NULL,
-		N_("Restart Target"),
-		NULL,
-		N_("restart the same target for debugging"),
-		G_CALLBACK (on_restart_debug_activate)
-	},
 	{
 		"ActionDebuggerAttachProcess",
 		"debugger-attach",
-		N_("_Attach to Process..."),
+		N_("_Debug Process..."),
 		NULL,
-		N_("Attach to a running program"),
+		N_("Start debugger and attach to a running program"),
 		G_CALLBACK (on_attach_to_project_action_activate)
 	},
+	{
+		"ActionDebuggerDebugRemote",
+		"debugger-remote-target",
+		N_("Debug _Remote Target..."),
+		NULL,
+		N_("Connect to a remote debugging target"),
+		G_CALLBACK (on_start_remote_debug_action_activate),
+	},
 	{
 		"ActionDebuggerStop",
 		GTK_STOCK_STOP,
@@ -957,7 +933,7 @@ static GtkActionEntry actions_stopped[] =
 {
 	{
 		"ActionDebuggerRunContinue",                   /* Action name */
-		GTK_STOCK_EXECUTE,                             /* Stock icon, if any */
+		GTK_STOCK_MEDIA_PLAY,                             /* Stock icon, if any */
 		N_("Run/_Continue"),                           /* Display label */
 		"F4",                                          /* short-cut */
 		N_("Continue the execution of the program"),   /* Tooltip */
@@ -983,7 +959,7 @@ static GtkActionEntry actions_stopped[] =
 		"ActionDebuggerStepOut",
 		"debugger-step-out",
 		N_("Step _Out"),                    
-		"F7",                              
+		"<shift>F5",                              
 		N_("Single step out of the function"), 
 		G_CALLBACK (on_step_out_action_activate) 
 	},
@@ -1072,11 +1048,10 @@ static gboolean
 dma_plugin_activate (AnjutaPlugin* plugin)
 {
 	DebugManagerPlugin *this;
-    static gboolean initialized = FALSE;
+	static gboolean initialized = FALSE;
 	AnjutaUI *ui;
-	GtkAction *action;
 	
-	DEBUG_PRINT ("DebugManagerPlugin: Activating Debug Manager plugin...");
+	DEBUG_PRINT ("%s", "DebugManagerPlugin: Activating Debug Manager plugin...");
 	this = ANJUTA_PLUGIN_DEBUG_MANAGER (plugin);
 	
     if (!initialized)
@@ -1095,30 +1070,30 @@ dma_plugin_activate (AnjutaPlugin* plugin)
 	g_signal_connect (this, "program-exited", G_CALLBACK (dma_plugin_program_loaded), this);
 	g_signal_connect (this, "program-moved", G_CALLBACK (dma_plugin_program_moved), this);
 	g_signal_connect (this, "signal-received", G_CALLBACK (dma_plugin_signal_received), this);
-	g_signal_connect (this, "location_changed", G_CALLBACK (dma_plugin_location_changed), this);
+	g_signal_connect (this, "location-changed", G_CALLBACK (dma_plugin_location_changed), this);
 	
 	/* Add all our debug manager actions */
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (plugin)->shell, NULL);
 	this->start_group =
-		anjuta_ui_add_action_group_entries (ui, "ActionGroupDebug",
+		anjuta_ui_add_action_group_entries (ui, "ActionGroupDebugStart",
 											_("Debugger operations"),
 											actions_start,
 											G_N_ELEMENTS (actions_start),
 											GETTEXT_PACKAGE, TRUE, this);
 	this->loaded_group =
-		anjuta_ui_add_action_group_entries (ui, "ActionGroupDebug",
+		anjuta_ui_add_action_group_entries (ui, "ActionGroupDebugLoaded",
 											_("Debugger operations"),
 											actions_loaded,
 											G_N_ELEMENTS (actions_loaded),
 											GETTEXT_PACKAGE, TRUE, this);
 	this->stopped_group =
-		anjuta_ui_add_action_group_entries (ui, "ActionGroupDebug",
+		anjuta_ui_add_action_group_entries (ui, "ActionGroupDebugStopped",
 											_("Debugger operations"),
 											actions_stopped,
 											G_N_ELEMENTS (actions_stopped),
 											GETTEXT_PACKAGE, TRUE, this);
 	this->running_group =
-		anjuta_ui_add_action_group_entries (ui, "ActionGroupDebug",
+		anjuta_ui_add_action_group_entries (ui, "ActionGroupDebugRunning",
 											_("Debugger operations"),
 											actions_running,
 											G_N_ELEMENTS (actions_running),
@@ -1148,19 +1123,22 @@ dma_plugin_activate (AnjutaPlugin* plugin)
 
 	/* Start debugger part */
 	this->start = dma_start_new (this);
-	
+
+	/* Shared libraries part */
+	this->sharedlibs = sharedlibs_new (this);
+
+	/* Signal part */
+	this->signals = signals_new (this);
 
 	dma_plugin_debugger_stopped (this, 0);
-	action = gtk_action_group_get_action (this->start_group, "ActionDebuggerRestartTarget");
-	gtk_action_set_sensitive (action, FALSE);
 	
 	/* Add watches */
 	this->project_watch_id = 
-		anjuta_plugin_add_watch (plugin, "project_root_uri",
+		anjuta_plugin_add_watch (plugin, IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI,
 								 value_added_project_root_uri,
 								 value_removed_project_root_uri, NULL);
 	this->editor_watch_id = 
-		anjuta_plugin_add_watch (plugin, "document_manager_current_editor",
+		anjuta_plugin_add_watch (plugin, IANJUTA_DOCUMENT_MANAGER_CURRENT_DOCUMENT,
 								 value_added_current_editor,
 								 value_removed_current_editor, NULL);
 						 
@@ -1177,7 +1155,7 @@ dma_plugin_deactivate (AnjutaPlugin* plugin)
 	DebugManagerPlugin *this;
 	AnjutaUI *ui;
 
-	DEBUG_PRINT ("DebugManagerPlugin: Deactivating Debug Manager plugin...");
+	DEBUG_PRINT ("%s", "DebugManagerPlugin: Deactivating Debug Manager plugin...");
 
 	this = ANJUTA_PLUGIN_DEBUG_MANAGER (plugin);
 
@@ -1220,6 +1198,12 @@ dma_plugin_deactivate (AnjutaPlugin* plugin)
 	dma_start_free (this->start);
 	this->start = NULL;
 
+	sharedlibs_free (this->sharedlibs);
+	this->sharedlibs = NULL;
+
+	signals_free (this->signals);
+	this->signals = NULL;
+
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (this)->shell, NULL);
 	anjuta_ui_remove_action_group (ui, this->start_group);
 	anjuta_ui_remove_action_group (ui, this->loaded_group);
@@ -1231,7 +1215,7 @@ dma_plugin_deactivate (AnjutaPlugin* plugin)
 		g_object_remove_weak_pointer (G_OBJECT (this->view), (gpointer*)(gpointer)&this->view);
         this->view = NULL;
 	}
-	
+
 	return TRUE;
 }
 
@@ -1283,7 +1267,7 @@ dma_plugin_instance_init (GObject* obj)
 static void
 dma_plugin_dispose (GObject* obj)
 {
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (G_OBJECT (obj)));
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
 /* finalize is the last destruction step. It must free all memory allocated
@@ -1304,7 +1288,7 @@ dma_plugin_finalize (GObject* obj)
 		g_object_remove_weak_pointer (G_OBJECT (self->current_editor), (gpointer *)(gpointer)&self->current_editor);
 	}
 	
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (G_OBJECT (obj)));
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 /* class_init intialize the class itself not the instance */
@@ -1325,9 +1309,36 @@ dma_plugin_class_init (GObjectClass* klass)
 /* Implementation of IAnjutaDebugManager interface
  *---------------------------------------------------------------------------*/
 
+static gboolean
+idebug_manager_start (IAnjutaDebugManager *plugin, const gchar *uri, GError **err)
+{
+	DebugManagerPlugin *self = ANJUTA_PLUGIN_DEBUG_MANAGER (plugin);
+
+	return dma_run_target (self->start, uri);
+}
+
+static gboolean
+idebug_manager_start_remote (IAnjutaDebugManager *plugin, const gchar *server, const gchar *uri, GError **err)
+{
+	DebugManagerPlugin *self = ANJUTA_PLUGIN_DEBUG_MANAGER (plugin);
+
+	return dma_run_remote_target (self->start, server, uri);
+}
+
+static gboolean
+idebug_manager_quit (IAnjutaDebugManager *plugin, GError **err)
+{
+	DebugManagerPlugin *self = ANJUTA_PLUGIN_DEBUG_MANAGER (plugin);
+
+	return dma_quit_debugger (self->start);
+}
+
 static void
 idebug_manager_iface_init (IAnjutaDebugManagerIface *iface)
 {
+	iface->start = idebug_manager_start;
+	iface->start_remote = idebug_manager_start_remote;
+	iface->quit = idebug_manager_quit;
 }
 
 ANJUTA_PLUGIN_BEGIN (DebugManagerPlugin, dma_plugin);
