@@ -32,7 +32,7 @@
 
 #include "sexy-icon-entry.h"
 
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 
 #include <gdk/gdkkeysyms.h>
 
@@ -488,7 +488,7 @@ dma_sparse_view_populate_popup (DmaSparseView *view,
 	gtk_widget_show (menu_item);
 
 	/* create goto menu_item. */
-	menu_item = gtk_menu_item_new_with_mnemonic ("_Goto address");
+	menu_item = gtk_menu_item_new_with_mnemonic (_("_Goto address"));
 	g_signal_connect (G_OBJECT (menu_item), "activate",
 			  G_CALLBACK (dma_sparse_view_goto_activate), view);
 	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
