@@ -31,14 +31,13 @@
 #include <string.h>
 #include <time.h>
 
-#include <gnome.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <libgnomevfs/gnome-vfs.h>
 #include <libanjuta/interfaces/ianjuta-file.h>
+#include <libanjuta/interfaces/ianjuta-file-savable.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
 #include <libanjuta/interfaces/ianjuta-macro.h>
 #include <libanjuta/interfaces/ianjuta-file.h>
 #include <libanjuta/interfaces/ianjuta-project-manager.h>
+#include <libanjuta/interfaces/ianjuta-vcs.h>
 
 #include "plugin.h"
 #include "file.h"
@@ -69,7 +68,7 @@ typedef struct _NewfileType
 {
 	gchar *name;
 	gchar *ext;
-	gboolean header;
+	gint header;
 	gboolean gpl;
 	gboolean template;
 	Cmt comment;
@@ -79,44 +78,47 @@ typedef struct _NewfileType
 
 
 NewfileType new_file_type[] = {
-	{N_("C Source File"), ".c", TRUE, TRUE, FALSE, CMT_C, LGE_C},
-	{N_("C/C++ Header File"), ".h", TRUE, TRUE, TRUE, CMT_C, LGE_HC},
-	{N_("C++ Source File"), ".cxx", TRUE, TRUE, FALSE, CMT_CPP, LGE_CPLUS},
-	{N_("C# Source File"), ".c#", TRUE, FALSE, FALSE, CMT_CPP, LGE_CSHARP},
-	{N_("Java Source File"), ".java", TRUE, TRUE, FALSE, CMT_CPP, LGE_JAVA},
-	{N_("Perl Source File"), ".pl", TRUE, TRUE, FALSE, CMT_P, LGE_PERL},
-	{N_("Python Source File"), ".py", FALSE, TRUE, FALSE, CMT_P, LGE_PYTHON},
-	{N_("Shell Script File"), ".sh", TRUE, TRUE, FALSE, CMT_P, LGE_SHELL},
-	{N_("Other"), NULL, FALSE, FALSE, FALSE, CMT_C, LGE_C}
+	{N_("C Source File"), ".c", LGE_HC, TRUE, TRUE, CMT_C, LGE_C},
+	{N_("C/C++ Header File"), ".h", -1, TRUE, TRUE, CMT_C, LGE_HC},
+	{N_("C++ Source File"), ".cxx", LGE_HC, TRUE, TRUE, CMT_CPP, LGE_CPLUS},
+	{N_("C# Source File"), ".c#", LGE_HC, FALSE, TRUE, CMT_CPP, LGE_CSHARP},
+	{N_("Java Source File"), ".java", -1, FALSE, FALSE, CMT_CPP, LGE_JAVA},
+	{N_("Perl Source File"), ".pl", -1, TRUE, TRUE, CMT_P, LGE_PERL},
+	{N_("Python Source File"), ".py", -1, TRUE, FALSE, CMT_P, LGE_PYTHON},
+	{N_("Shell Script File"), ".sh", -1, TRUE, TRUE, CMT_P, LGE_SHELL},
+	{N_("Other"), NULL, -1, FALSE, FALSE, CMT_C, LGE_C}
 };
 
 
-typedef enum _Lsc
-{
-	GPL,
-	LGPL
-} Lsc;
-
 typedef struct _NewlicenseType
 {
 	gchar *name;
-	Lsc type;
+	const gchar* type;
 } NewlicenseType;
 
 NewlicenseType new_license_type[] = {
-	{N_("General Public License (GPL)"), GPL},
-	{N_("Lesser General Public License (LGPL)"), LGPL}
+	{N_("General Public License (GPL)"), "GPL"},
+	{N_("Lesser General Public License (LGPL)"), "LGPL"},
+	{N_("BSD Public License"), "BSD"}
 };
 
 static NewFileGUI *nfg = NULL;
 
 
 static gboolean create_new_file_dialog(IAnjutaDocumentManager *docman);
-static void insert_notice_gpl (IAnjutaMacro* macro, gint comment_type);
-static void insert_notice_lgpl (IAnjutaMacro* macro, gint comment_type);
-static void insert_notice(IAnjutaMacro* macro, gint license_type, gint comment_type);
+static void insert_notice(IAnjutaMacro* macro, const gchar* license_type, gint comment_type);
 static void insert_header(IAnjutaMacro* macro, gint source_type);
 
+static void
+on_add_to_project_toggled (GtkWidget* toggle_button, NewFileGUI *gui)
+{
+	gboolean status = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(toggle_button));
+	gtk_widget_set_sensitive (gui->add_to_repository, status);
+	if (!status)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(gui->add_to_repository),
+		                              FALSE);
+}
+
 void
 display_new_file(AnjutaFileWizardPlugin *plugin,
 				 IAnjutaDocumentManager *docman)
@@ -138,6 +140,10 @@ display_new_file(AnjutaFileWizardPlugin *plugin,
        if (manager)
 			caps = ianjuta_project_manager_get_capabilities (manager, NULL);
 	}
+
+	g_signal_connect (nfg->add_to_project, "toggled", 
+	                  G_CALLBACK(on_add_to_project_toggled),
+	                  nfg);
 	
 	if ((caps & IANJUTA_PROJECT_MANAGER_CAN_ADD_SOURCE) == FALSE) {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (nfg->add_to_project),
@@ -152,8 +158,6 @@ display_new_file(AnjutaFileWizardPlugin *plugin,
 	}
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (nfg->add_to_repository),
 								  FALSE);
-	/* FIXME: fix the problem with the repository add, then enable this check-button */
-	gtk_widget_set_sensitive (nfg->add_to_repository, FALSE);
 	
 	if (nfg && !(nfg->showing))
 	{
@@ -222,41 +226,6 @@ on_new_file_cancelbutton_clicked(GtkWidget *window, GdkEvent *event,
 	return TRUE;
 }
 
-static gboolean
-confirm_file_overwrite (AnjutaPlugin* plugin, const gchar *uri)
-{
-	GnomeVFSURI *vfs_uri;
-	gboolean ret = TRUE;
-	
-	vfs_uri = gnome_vfs_uri_new (uri);
-	if (gnome_vfs_uri_exists (vfs_uri))
-	{
-		GtkWidget *dialog;
-		gint res;
-		dialog = gtk_message_dialog_new (GTK_WINDOW (ANJUTA_PLUGIN (plugin)->shell),
-										 GTK_DIALOG_DESTROY_WITH_PARENT,
-										 GTK_MESSAGE_QUESTION,
-										 GTK_BUTTONS_NONE,
-										 _("The file '%s' already exists.\n"
-										   "Do you want to replace it with the "
-										   "one you are saving?"),
-										 uri);
-		gtk_dialog_add_button (GTK_DIALOG(dialog),
-							   GTK_STOCK_CANCEL,
-							   GTK_RESPONSE_CANCEL);
-		anjuta_util_dialog_add_button (GTK_DIALOG (dialog),
-								  _("_Replace"),
-								  GTK_STOCK_REFRESH,
-								  GTK_RESPONSE_YES);
-		res = gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
-		if (res != GTK_RESPONSE_YES)
-			ret = FALSE;
-	}
-	gnome_vfs_uri_unref (vfs_uri);
-	return ret;
-}
-
 gboolean
 on_new_file_okbutton_clicked(GtkWidget *window, GdkEvent *event,
 			                 gboolean user_data)
@@ -265,14 +234,17 @@ on_new_file_okbutton_clicked(GtkWidget *window, GdkEvent *event,
 	GtkWidget *checkbutton;
 	GtkWidget *optionmenu;
 	const gchar *name;
+	gchar *header_name = NULL;
 	gint sel;
-	gint license_type;
+	const gchar* license_type;
 	gint comment_type;
 	gint source_type;
 	IAnjutaDocumentManager *docman;
 	GtkWidget *toplevel;
 	IAnjutaMacro* macro;
 	IAnjutaEditor *te = NULL;
+	IAnjutaEditor *teh = NULL;
+	gboolean ok = TRUE;
 	
 	toplevel= gtk_widget_get_toplevel (window);
 	docman = IANJUTA_DOCUMENT_MANAGER (g_object_get_data (G_OBJECT(toplevel),
@@ -281,44 +253,17 @@ on_new_file_okbutton_clicked(GtkWidget *window, GdkEvent *event,
 		                       IAnjutaMacro, NULL);
 	entry = glade_xml_get_widget(nfg->xml, NEW_FILE_ENTRY);
 	name = gtk_entry_get_text(GTK_ENTRY(entry));
-	
-	if (nfg->plugin->top_dir &&
-		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (nfg->add_to_project)))
-	{
-		IAnjutaProjectManager *pm;
-		GnomeVFSHandle *vfs_write;
-		gchar* file_uri;
-		
-		pm = anjuta_shell_get_interface (ANJUTA_PLUGIN(docman)->shell, 
-										 IAnjutaProjectManager, NULL);
-		g_return_val_if_fail (pm != NULL, FALSE);
-		
-		file_uri = ianjuta_project_manager_add_source (pm, name, "", NULL);
-		if (!file_uri)
-			return FALSE;
-		
-		/* Create empty file */
-		if (!confirm_file_overwrite (ANJUTA_PLUGIN (nfg->plugin), file_uri) ||
-			gnome_vfs_create (&vfs_write, file_uri, GNOME_VFS_OPEN_WRITE,
-							  FALSE, 0664) != GNOME_VFS_OK ||
-			gnome_vfs_close(vfs_write) != GNOME_VFS_OK)
-		{
-			g_free (file_uri);
-			return FALSE;
-		}
-		ianjuta_file_open (IANJUTA_FILE (docman), file_uri, NULL);
-		g_free (file_uri);
-	}
+
+	/* Create main file */
+	if (name && strlen (name) > 0)
+		te = ianjuta_document_manager_add_buffer (docman, name, NULL, NULL);
 	else
-	{
-		if (name && strlen (name) > 0)
-			te = ianjuta_document_manager_add_buffer (docman, name, "", NULL);
-		else
-			te = ianjuta_document_manager_add_buffer (docman, "", "", NULL);
-		if (te == NULL)
-			return FALSE;
-	}
+		te = ianjuta_document_manager_add_buffer (docman, "", NULL, NULL);
 	
+	if (te == NULL)
+		return FALSE;
+	
+	/* Create header file */
 	optionmenu = glade_xml_get_widget(nfg->xml, NEW_FILE_TYPE);
 	source_type = gtk_option_menu_get_history(GTK_OPTION_MENU(optionmenu));
 	
@@ -326,9 +271,42 @@ on_new_file_okbutton_clicked(GtkWidget *window, GdkEvent *event,
 	if (GTK_WIDGET_SENSITIVE(checkbutton) && 
 			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbutton)))
 	{
-		insert_header(macro, source_type);
+		if (name && strlen (name) > 0)
+		{
+			const gchar *old_ext = strrchr (name,'.');
+			const gchar *new_ext =  new_file_type[new_file_type[source_type].header].ext;
+			
+			if (old_ext == NULL)
+			{
+				header_name = g_strconcat (name, new_ext, NULL);
+			}
+			else
+			{
+				header_name = g_strndup (name, old_ext - name + strlen(new_ext));
+				strcpy(&header_name[old_ext - name], new_ext);
+			}
+			teh = ianjuta_document_manager_add_buffer (docman, header_name, NULL, NULL);
+		}
+		else
+		{
+			teh = ianjuta_document_manager_add_buffer (docman, "", NULL, NULL);
+		}
+		ianjuta_document_manager_set_current_document (docman, IANJUTA_DOCUMENT(te), NULL);		
 	}
-		
+
+	checkbutton = glade_xml_get_widget(nfg->xml, NEW_FILE_TEMPLATE);
+	if (GTK_WIDGET_SENSITIVE(checkbutton) && 
+			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbutton)))
+	{
+		insert_header(macro, source_type);
+		if (teh != NULL)
+		{
+			ianjuta_document_manager_set_current_document (docman, IANJUTA_DOCUMENT(teh), NULL);		
+			insert_header (macro, new_file_type[source_type].header);
+			ianjuta_document_manager_set_current_document (docman, IANJUTA_DOCUMENT(te), NULL);		
+		}
+	}
+	
 	checkbutton = glade_xml_get_widget(nfg->xml, NEW_FILE_LICENSE);
 	if (GTK_WIDGET_SENSITIVE(checkbutton) && 
 			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbutton)))
@@ -339,19 +317,81 @@ on_new_file_okbutton_clicked(GtkWidget *window, GdkEvent *event,
 		comment_type = new_file_type[source_type].comment;
 		                                  
 		insert_notice(macro, license_type, comment_type);		
+		if (teh != NULL)
+		{
+			comment_type = new_file_type[new_file_type[source_type].header].comment;
+			ianjuta_document_manager_set_current_document (docman, IANJUTA_DOCUMENT(teh), NULL);		
+			insert_notice(macro, license_type, comment_type);		
+			ianjuta_document_manager_set_current_document (docman, IANJUTA_DOCUMENT(te), NULL);		
+		}
 	}
 	
-	checkbutton = glade_xml_get_widget(nfg->xml, NEW_FILE_TEMPLATE);
-	if (GTK_WIDGET_SENSITIVE(checkbutton) && 
-			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbutton)))
+	/* Add file to project */
+	if (nfg->plugin->top_dir &&
+		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (nfg->add_to_project)))
 	{
-		ianjuta_macro_insert(macro, "Header_h", NULL);
+		IAnjutaProjectManager *pm;
+		GFile* file;
+		GList *names = NULL;
+		GList *uri_list;
+		
+		pm = anjuta_shell_get_interface (ANJUTA_PLUGIN(docman)->shell, 
+										 IAnjutaProjectManager, NULL);
+		g_return_val_if_fail (pm != NULL, FALSE);
+
+		if (teh) names = g_list_prepend (names, header_name);
+		names = g_list_prepend (names, (gpointer) name);
+		uri_list = ianjuta_project_manager_add_sources (pm, names, NULL, NULL);
+		g_list_free (names);
+		
+		if (uri_list)
+		{
+			/* Save main file */
+			file = g_file_new_for_uri ((const gchar *)uri_list->data);
+			ianjuta_file_savable_save_as (IANJUTA_FILE_SAVABLE (te), file, NULL);		
+			g_object_unref (file);
+			
+			if (uri_list->next)
+			{
+				/* Save header file */
+				file = g_file_new_for_uri ((const gchar *)uri_list->next->data);
+				ianjuta_file_savable_save_as (IANJUTA_FILE_SAVABLE (teh), file, NULL);		
+				g_object_unref (file);
+			}		
+
+
+			/* Add to repository */
+			if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (nfg->add_to_repository)))
+			{
+				IAnjutaVcs* ivcs = anjuta_shell_get_interface (ANJUTA_PLUGIN(docman)->shell, 
+										 IAnjutaVcs, NULL);
+				if (ivcs)
+				{					
+					GList* files = NULL;
+					GList* node;
+					AnjutaAsyncNotify* notify = anjuta_async_notify_new();
+					for (node = uri_list; node != NULL; node = g_list_next (node))
+					{
+						files = g_list_append (files, g_file_new_for_uri (node->data));
+					}
+					ianjuta_vcs_add (ivcs, files, notify, NULL);
+					g_list_foreach (files, (GFunc) g_object_unref, NULL);
+				}
+			}
+			g_list_foreach (uri_list, (GFunc)g_free, NULL);
+			g_list_free (uri_list);
+		}
+		else
+		{
+			ok = FALSE;
+		}
 	}
+	g_free (header_name);
 	
 	gtk_widget_hide (nfg->dialog);
 	nfg->showing = FALSE;
 	
-	return TRUE;
+	return ok;
 }
 
 void
@@ -389,7 +429,7 @@ on_new_file_type_changed (GtkOptionMenu   *optionmenu, gpointer user_data)
 	sel = gtk_option_menu_get_history(optionmenu);
 	
 	widget = glade_xml_get_widget(nfg->xml, NEW_FILE_HEADER);
-	gtk_widget_set_sensitive(widget, new_file_type[sel].header);
+	gtk_widget_set_sensitive(widget, new_file_type[sel].header >= 0);
 	widget = glade_xml_get_widget(nfg->xml, NEW_FILE_LICENSE);
 	gtk_widget_set_sensitive(widget, new_file_type[sel].gpl);
 	widget = glade_xml_get_widget(nfg->xml, NEW_FILE_TEMPLATE);
@@ -417,61 +457,32 @@ on_new_file_license_toggled(GtkToggleButton *button, gpointer user_data)
 	widget = glade_xml_get_widget(nfg->xml, NEW_FILE_MENU_LICENSE);
 	gtk_widget_set_sensitive(widget, gtk_toggle_button_get_active(button));
 }
- 
-static void
-insert_notice_gpl (IAnjutaMacro* macro, gint comment_type)
-{
-	switch (comment_type)
-	{
-		case CMT_C:
-			ianjuta_macro_insert(macro, "/* GPL */", NULL);
-			break;
-		case CMT_CPP:
-			ianjuta_macro_insert(macro, "// GPL", NULL);;
-			break;
-		case CMT_P:
-			ianjuta_macro_insert(macro, "# GPL", NULL);;
-			break;
-		default:
-			ianjuta_macro_insert(macro, "/* GPL */", NULL);;
-			break;
-	}
-}
 
 static void
-insert_notice_lgpl (IAnjutaMacro* macro, gint comment_type)
+insert_notice(IAnjutaMacro* macro, const gchar* license_type, gint comment_type)
 {
+	const gchar *template;
+	gchar *name;
+
 	switch (comment_type)
 	{
 		case CMT_C:
-			ianjuta_macro_insert(macro, "/* LGPL */", NULL);
+			template = "/* %s */";
 			break;
 		case CMT_CPP:
-			ianjuta_macro_insert(macro, "// LGPL", NULL);;
+			template = "// %s";
 			break;
 		case CMT_P:
-			ianjuta_macro_insert(macro, "# LGPL", NULL);;
+			template = "# %s";
 			break;
 		default:
-			ianjuta_macro_insert(macro, "/* LGPL */", NULL);;
+			template = "/* %s */";
 			break;
 	}
-}
-static void
-insert_notice(IAnjutaMacro* macro, gint license_type, gint comment_type)
-{
-	switch (license_type)
-	{
-		case GPL:
-			insert_notice_gpl(macro, comment_type);
-			break;
-		case LGPL :
-			insert_notice_lgpl(macro, comment_type);
-			break;
-		default:
-			;
-			break;
-	}	
+
+	name = g_strdup_printf(template, license_type);
+	ianjuta_macro_insert(macro, name, NULL);
+	g_free (name);
 }
 
 static void
