@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2002, 2003  Sebastian Rittau <srittau@jroger.in-berlin.de>
- * $Id: egg-datetime.c 4655 2009-01-31 16:30:54Z sgranjoux $
+ * $Id: egg-datetime.c 4773 2009-02-20 20:22:46Z aklapper $
  *
  * Based on GnomeDateEdit by Miguel de Icaza.
  *
@@ -535,7 +535,7 @@ egg_datetime_init (EggDateTime *edt)
 	cal_options = GTK_CALENDAR_SHOW_DAY_NAMES | GTK_CALENDAR_SHOW_HEADING;
 	if (priv->week_start_monday)
 		cal_options |= GTK_CALENDAR_WEEK_START_MONDAY;
-	gtk_calendar_display_options (GTK_CALENDAR (priv->calendar), cal_options);
+	gtk_calendar_set_display_options (GTK_CALENDAR (priv->calendar), cal_options);
 	gtk_box_pack_start(GTK_BOX(vbox), priv->calendar, TRUE, TRUE,0);
 	g_signal_connect_swapped (G_OBJECT (priv->calendar), "day-selected",
 			G_CALLBACK (cal_popup_changed), edt);
