@@ -62,6 +62,7 @@ void on_search_regex_toggled (GtkToggleButton *togglebutton, gpointer user_data)
 void on_search_action_changed (GtkComboBox *combo, gpointer user_data);
 void on_search_target_changed(GtkComboBox *combo, gpointer user_data);
 void on_search_expression_changed(GtkComboBox *combo, gpointer user_data);
+void on_search_expression_entry_changed(GtkEntry *entry, gpointer user_data);
 void on_actions_no_limit_clicked(GtkButton *button, gpointer user_data);
 void on_search_button_close_clicked(GtkButton *button, gpointer user_data);
 void on_search_button_close_clicked(GtkButton *button, gpointer user_data);
@@ -228,7 +229,6 @@ write_message_pane(IAnjutaMessageView* view, FileBuffer *fb, SearchEntry *se, Ma
 static gboolean on_message_clicked (GObject* object, gchar* message, gpointer data);
 static void on_message_view_destroyed (gpointer unused, GObject* where_the_object_was);
 static void on_message_buffer_flush (IAnjutaMessageView *view, const gchar *one_line, gpointer data);
-static void save_not_opened_files(FileBuffer *fb);
 static gboolean replace_in_not_opened_files(FileBuffer *fb, MatchInfo *mi, gchar *repl_str);
 static void search_set_action(SearchAction action);
 static void search_set_target(SearchRangeType target);
@@ -283,9 +283,9 @@ search_and_replace (void)
 	FileBuffer *fb;
 	static MatchInfo *mi;
 	Search *s;
-	gint offset;
+	gint offset;			/* offset due to previous replace */
 	gint found_line = 0;
-	static gint os = 0;
+	static gint os = 0;		/* Keep previous offset when doing interactibe S&R */
 	gint nb_results;
 	static long start_sel = 0;
 	static long end_sel = 0;
@@ -355,21 +355,25 @@ search_and_replace (void)
 		found_line = (s->action == SA_BOOKMARK) ? -1 : 1;
 
 		se = (SearchEntry *) tmp->data;
-		if (flag_select)
-		{
-			se->start_pos = start_sel;
-			se->end_pos = end_sel;
-		}
-		else
-			end_sel = se->end_pos;
+		
 		if (SE_BUFFER == se->type)
 			fb = file_buffer_new_from_te(se->te);
 		else /* if (SE_FILE == se->type) */
-			fb = file_buffer_new_from_path(se->path, NULL, -1, 0);
-
+			fb = file_buffer_new_from_uri(se->uri);
+		
 		if (fb && fb->buf)
-		{		
-			fb->pos = se->start_pos;
+		{
+			if (flag_select)
+			{
+				se->start_pos = g_utf8_strlen (fb->buf, start_sel);
+				se->end_pos = g_utf8_strlen (fb->buf, end_sel);
+			}
+			else if (se->end_pos != -1)
+			 {
+				end_sel = g_utf8_offset_to_pointer (fb->buf, se->end_pos) - fb->buf;
+			 }
+			
+			fb->pos = g_utf8_offset_to_pointer (fb->buf, se->start_pos) - fb->buf;
 			offset = 0;
 		//FIXME enable clearing of marks by some means other than a 0-match search
 			if (s->action == SA_HIGHLIGHT)	
@@ -378,10 +382,10 @@ search_and_replace (void)
 			while (interactive || 
 				NULL != (mi = get_next_match(fb, s->range.direction, &(s->expr))))
 			{
-				if ((s->range.direction == SD_BACKWARD) && (mi->pos < se->end_pos))
+				if ((s->range.direction == SD_BACKWARD) && (mi->pos < end_sel))
 						break; 
-				if ((s->range.direction != SD_BACKWARD) && ((se->end_pos != -1) &&
-					(mi->pos+mi->len > se->end_pos)))
+				if ((s->range.direction != SD_BACKWARD) && ((end_sel != 0) &&
+					(mi->pos+mi->len > end_sel)))
 						break; 
 				nb_results++; 
 				if (nb_results > sr->search.expr.actions_max)
@@ -402,10 +406,14 @@ search_and_replace (void)
 
 						if (IANJUTA_INDICABLE (fb->te))
 						{
+							gint char_pos;
 							IAnjutaIterable *start_pos, *end_pos;
 							/* end-location is correct for sourceview, 1-too-big for scintilla */
-							start_pos = ianjuta_editor_get_position_from_offset (fb->te, mi->pos, NULL);
-							end_pos = ianjuta_editor_get_position_from_offset (fb->te, mi->pos + mi->len, NULL);
+
+							char_pos = g_utf8_strlen (fb->buf, mi->pos);
+							start_pos = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
+							char_pos += g_utf8_strlen (fb->buf + mi->pos, mi->len);
+							end_pos = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
 							ianjuta_indicable_set (IANJUTA_INDICABLE(fb->te),
 												   start_pos, end_pos,
 												   IANJUTA_INDICABLE_IMPORTANT, NULL);
@@ -417,14 +425,12 @@ search_and_replace (void)
 					case SA_BOOKMARK:
 						if (found_line != mi->line)
 						{
-							GFile* file = g_file_new_for_uri (fb->uri);
 							found_line = mi->line + 1; /* different line count between search and editor */
 							ianjuta_document_manager_add_bookmark (sr->docman,
-																   file,
+																   fb->file,
 																   found_line,
 																   NULL);
-							g_object_unref (file);			  
-						}
+	 					}
 						break;
 						
 					case SA_SELECT:
@@ -434,19 +440,23 @@ search_and_replace (void)
 								ianjuta_editor_goto_line (fb->te, mi->line, NULL);
 							else
 							{
-								GFile* file = g_file_new_for_uri (fb->uri);
-								fb->te = ianjuta_document_manager_goto_file_line_mark
-									(sr->docman, file, mi->line, FALSE, NULL);
-								g_object_unref (file);
+									fb->te = ianjuta_document_manager_goto_file_line_mark
+									(sr->docman, fb->file, mi->line, FALSE, NULL);
 							}
 							found_line = mi->line;
 						}
 						{
-							IAnjutaIterable* start = ianjuta_editor_get_position_from_offset (fb->te, mi->pos, NULL);
-							IAnjutaIterable* end = ianjuta_editor_get_position_from_offset (fb->te, mi->pos + mi->len, NULL);
+							gint char_pos;
+							IAnjutaIterable *start, *end;
+
+							char_pos = g_utf8_strlen (fb->buf, mi->pos);
+							start = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
+							char_pos += g_utf8_strlen (fb->buf + mi->pos, mi->len);
+							end = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
 							ianjuta_editor_selection_set(IANJUTA_EDITOR_SELECTION (fb->te), 
 														 start,
 														 end,
+														 TRUE,
 														 NULL);
 							g_object_unref (start);
 							g_object_unref (end);
@@ -459,26 +469,30 @@ search_and_replace (void)
 					
 					case SA_REPLACE:
 						if (found_line != mi->line || fb->te == NULL)
-							{
+						{
 							if (fb->te)
 								ianjuta_editor_goto_line (fb->te, mi->line, NULL);
 							else
 							{
-								GFile* file = g_file_new_for_uri (fb->uri);
 								fb->te = ianjuta_document_manager_goto_file_line_mark
-									(sr->docman, file, mi->line, FALSE, NULL);
-								g_object_unref (file);
+									(sr->docman, fb->file, mi->line, FALSE, NULL);
 							}
 							found_line = mi->line;
-							}
+						}
 
 						if (!interactive)
 						{
-							IAnjutaIterable* start = ianjuta_editor_get_position_from_offset (fb->te, mi->pos - offset, NULL);
-							IAnjutaIterable* end = ianjuta_editor_get_position_from_offset (fb->te, mi->pos - offset + mi->len, NULL);
+							gint char_pos;
+							IAnjutaIterable *start, *end;
+
+							char_pos = g_utf8_strlen (fb->buf, mi->pos - offset);
+							start = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
+							char_pos += g_utf8_strlen (fb->buf + mi->pos - offset, mi->len);
+							end = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
 							ianjuta_editor_selection_set(IANJUTA_EDITOR_SELECTION (fb->te), 
 														 start,
 														 end,
+														 TRUE,
 														 NULL);
 							g_object_unref (start);
 							g_object_unref (end);
@@ -491,23 +505,29 @@ search_and_replace (void)
 							{
 									g_free (ch);
 								ch = regex_backref (mi, fb);
-								}
 							}
+						}
 						else
 						{
-						if (ch && sr->replace.regex && sr->search.expr.regex)
-						{
+							if (ch && sr->replace.regex && sr->search.expr.regex)
+							{
 								g_free (sr->replace.repl_str);
 								sr->replace.repl_str = g_strdup (ch);
-							g_free (ch);
+								g_free (ch);
 								ch = NULL;
-						}
+							}
 							{
-								IAnjutaIterable* start = ianjuta_editor_get_position_from_offset (fb->te, mi->pos - os, NULL);
-								IAnjutaIterable* end = ianjuta_editor_get_position_from_offset (fb->te, mi->pos + mi->len - os, NULL);
+								gint char_pos;
+								IAnjutaIterable *start, *end;
+
+								char_pos = g_utf8_strlen (fb->buf, mi->pos - os);
+								start = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
+								char_pos += g_utf8_strlen (fb->buf + mi->pos - os, mi->len);
+								end = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
 								ianjuta_editor_selection_set(IANJUTA_EDITOR_SELECTION (fb->te),  
 															 start,														 
 															 end,
+															 TRUE,
 															 NULL);
 								ianjuta_editor_selection_replace(IANJUTA_EDITOR_SELECTION (fb->te), 
 																 sr->replace.repl_str,
@@ -516,10 +536,10 @@ search_and_replace (void)
 								g_object_unref (start);
 								g_object_unref (end);
 							}
-						if (se->direction != SD_BACKWARD)
-							offset += mi->len - (sr->replace.repl_str?strlen(sr->replace.repl_str):0);
+							if (se->direction != SD_BACKWARD)
+								offset += mi->len - (sr->replace.repl_str?strlen(sr->replace.repl_str):0);
 						
-						interactive = FALSE;
+							interactive = FALSE;
 						}
 						break;
 
@@ -538,11 +558,17 @@ search_and_replace (void)
 						}
 						else
 						{
-							IAnjutaIterable* start = ianjuta_editor_get_position_from_offset (fb->te, mi->pos - offset, NULL);
-							IAnjutaIterable* end = ianjuta_editor_get_position_from_offset (fb->te, mi->pos + mi->len - offset, NULL);
+							gint char_pos;
+							IAnjutaIterable *start, *end;
+
+							char_pos = g_utf8_strlen (fb->buf, mi->pos - offset);
+							start = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
+							char_pos += g_utf8_strlen (fb->buf + mi->pos - offset, mi->len);
+							end = ianjuta_editor_get_position_from_offset (fb->te, char_pos, NULL);
 							ianjuta_editor_selection_set(IANJUTA_EDITOR_SELECTION (fb->te),  
 														 start,
 														 end,
+														 TRUE,
 														 NULL);
 							ianjuta_editor_selection_replace(IANJUTA_EDITOR_SELECTION (fb->te), 
 															 sr->replace.repl_str,
@@ -579,14 +605,12 @@ search_and_replace (void)
 			}
 			if (save_file)
 			{
-				save_not_opened_files (fb);
+				g_file_replace_contents (fb->file, fb->buf, fb->len, NULL, FALSE, G_FILE_CREATE_NONE, NULL, NULL, NULL);
 				save_file = FALSE;
 			}
 			
 		}
 		file_buffer_free (fb);
-		g_free (se->path);
-		g_free (se);
 
 		if (SA_SELECT == s->action && nb_results > 0)
 			break;
@@ -598,8 +622,7 @@ search_and_replace (void)
 		s->range.type == SR_SELECTION)
 			flag_select = TRUE;
 	
-	if (entries)
-		g_list_free (entries);
+	free_search_entries  (entries);
 	
 	if (s->action == SA_FIND_PANE)
 	{
@@ -629,13 +652,43 @@ write_message_pane(IAnjutaMessageView* view, FileBuffer *fb, SearchEntry *se,
 {
 	gchar *match_line = file_match_line_from_pos(fb, mi->pos);
 	int line = mi->line;
-	char buf[BUFSIZ];
+	gchar *buf;
+	gchar *path = NULL;
 	
 	if (se->type == SE_FILE)
 		++line;
-    snprintf(buf, BUFSIZ, "%s:%d:%s\n", fb->path, line, match_line);
+	if (fb->file != NULL)
+	{
+		gchar *dir_uri = NULL;	
+		
+		anjuta_shell_get (ANJUTA_PLUGIN(sr->docman)->shell,
+							  "project_root_uri", G_TYPE_STRING,
+							  &dir_uri, NULL);
+		if (dir_uri != NULL)
+		{
+			GFile *root_file = g_file_new_for_uri (dir_uri);
+			
+			g_free (dir_uri);
+			path = g_file_get_relative_path (root_file, fb->file);
+			g_object_unref (root_file);
+		}
+		
+		if (path == NULL)
+		{
+			path = g_file_get_path (fb->file);
+		}
+	}
+	else
+	{
+		g_return_if_fail (se->te != NULL);
+		
+		path = g_strdup (ianjuta_document_get_filename (IANJUTA_DOCUMENT (se->te), NULL));
+	}
+	buf = g_strdup_printf ("%s:%d:%s\n", path, line, match_line);
+	g_free (path);
 	g_free(match_line);
 	ianjuta_message_view_buffer_append (view, buf, NULL);
+	g_free (buf);
 }
 
 static void
@@ -656,10 +709,10 @@ static gboolean
 on_message_clicked (GObject* object, gchar* message, gpointer data)
 {
 	gchar *ptr, *ptr2;
-	gchar *path, *nline;
+	gchar *path, *nline, *real_path = NULL, *project_uri;
 	GFile* file;
 	gint line;
-		
+	
 	if (!(ptr = g_strstr_len(message, strlen(message), ":")) )
 		return FALSE;
 	path = g_strndup(message, ptr - message);
@@ -670,52 +723,32 @@ on_message_clicked (GObject* object, gchar* message, gpointer data)
 	nline = g_strndup(ptr, ptr2 - ptr);
 	line = atoi(nline);
 	
-	file = g_file_new_for_path (path); 
+	anjuta_shell_get (ANJUTA_PLUGIN(sr->docman)->shell,
+	                  "project_root_uri", G_TYPE_STRING,
+	                  &project_uri, NULL);
+	
+	if (project_uri && strlen(project_uri))
+	{
+		gchar* project_path = g_filename_from_uri (project_uri, NULL, NULL);
+		if (project_path)
+		{
+			real_path = g_build_filename (project_path, path, NULL);
+			g_free(path);
+		}
+		g_free(project_path);
+	}
+	if (!real_path)
+		real_path = path;
+	
+	file = g_file_new_for_path (real_path); 
 	ianjuta_document_manager_goto_file_line_mark (sr->docman, file, line, TRUE, NULL);
 	g_object_unref (file);
-	g_free(path);
+	g_free(real_path);
 	g_free(nline);
+	g_free(project_uri);
 	return FALSE;
 }
 
-static void
-save_not_opened_files(FileBuffer *fb)
-{
-	GFile *file;
-	GOutputStream *os;
-	gsize written;
-	gsize size;
-	gchar *buffer;
-
-	file = g_file_new_for_uri (fb->uri);
-	os = G_OUTPUT_STREAM (g_file_replace (file, 
-			NULL,
-			FALSE,
-			G_FILE_CREATE_NONE,
-			NULL,
-			NULL));
-	if (os == NULL)
-	{
-		g_object_unref (file);
-		return;
-	}
-
-	buffer = fb->buf;
-	size = fb->len;
-	do
-	{
-		written = g_output_stream_write (os, 
-				buffer, size, NULL, NULL);
-		
-		size -= written;
-		buffer += size;
-	}
-	while (written != -1 && size > 0);
-	g_output_stream_close(os, NULL, NULL);
-	g_object_unref (os);
-	g_object_unref (file);
-}
-
 static gboolean
 replace_in_not_opened_files(FileBuffer *fb, MatchInfo *mi, gchar *repl_str)
 {
@@ -1282,7 +1315,7 @@ create_dialog(void)
 			/* Get child of GtkComboBoxEntry */
 			w->widget = GTK_BIN(w->widget)->child;
 		}
-		gtk_widget_ref(w->widget);
+		g_object_ref(w->widget);
 		if (GE_COMBO == w->type && NULL != w->extra)
 		{
 			search_set_popdown_map(GTK_COMBO_BOX(w->widget), (AnjutaUtilStringMap *)w->extra);
@@ -1291,6 +1324,10 @@ create_dialog(void)
 
 	widget = sr_get_gladewidget(SEARCH_STRING_COMBO)->widget;
 	g_signal_connect (widget, "changed", G_CALLBACK (on_search_expression_changed), NULL);
+	/* Entry in the GtkComboBoxEntry */
+	widget = GTK_BIN (widget)->child;
+	gtk_entry_set_activates_default (GTK_ENTRY(widget), TRUE);
+	g_signal_connect (widget, "changed", G_CALLBACK (on_search_expression_entry_changed), NULL);
 	widget = sr_get_gladewidget(SEARCH_STRING)->widget;
 	g_signal_connect (widget, "activate", G_CALLBACK (on_search_expression_activate), NULL);
 	widget = sr_get_gladewidget(REPLACE_STRING)->widget;
@@ -1756,10 +1793,19 @@ on_search_expression_changed(GtkComboBox *combo, gpointer user_data)
 	GtkWidget *widget = sr_get_gladewidget(SEARCH_BUTTON)->widget;
 	gboolean sensitive;
 
-	sensitive = *gtk_entry_get_text (GTK_ENTRY (search_entry)) == '\0' ? FALSE: TRUE;
+	sensitive = strlen(gtk_entry_get_text (GTK_ENTRY (search_entry))) > 0;
 	gtk_widget_set_sensitive (widget, sensitive);
 }
 
+void
+on_search_expression_entry_changed(GtkEntry *entry, gpointer user_data)
+{
+	GtkWidget *widget = sr_get_gladewidget(SEARCH_BUTTON)->widget;
+	gboolean sensitive;
+
+	sensitive = *gtk_entry_get_text (GTK_ENTRY (entry)) == '\0' ? FALSE: TRUE;
+	gtk_widget_set_sensitive (widget, sensitive);
+}
 
 void
 on_actions_no_limit_clicked(GtkButton *button, gpointer user_data)
