@@ -43,7 +43,6 @@
 
 #define COMBO_STYLES "combo_styles"
 #define SOURCEVIEW_STYLE "sourceview.style"
-#define SOURCEVIEW_DEFAULT_STYLE "classic"
 
 #define FONT_USE_THEME_BUTTON "preferences_toggle:bool:1:0:sourceview.font.use_theme"
 #define FONT_BUTTON "preferences_font:font:Monospace 12:0:sourceview.font"
@@ -63,7 +62,7 @@ on_font_check_toggled(GtkToggleButton* button, GladeXML* gxml)
 static gboolean
 sourceview_plugin_activate (AnjutaPlugin *plugin)
 {	
-	DEBUG_PRINT ("SourceviewPlugin: Activating SourceviewPlugin plugin ...");
+	DEBUG_PRINT ("%s", "SourceviewPlugin: Activating SourceviewPlugin plugin ...");
 
 	return TRUE;
 }
@@ -71,7 +70,7 @@ sourceview_plugin_activate (AnjutaPlugin *plugin)
 static gboolean
 sourceview_plugin_deactivate (AnjutaPlugin *plugin)
 {
-	DEBUG_PRINT ("SourceviewPlugin: Dectivating SourceviewPlugin plugin ...");
+	DEBUG_PRINT ("%s", "SourceviewPlugin: Dectivating SourceviewPlugin plugin ...");
 	
 	return TRUE;
 }
@@ -120,14 +119,11 @@ ieditor_factory_new_editor(IAnjutaEditorFactory* factory,
 	gchar* current_style = anjuta_preferences_get (prefs, SOURCEVIEW_STYLE);
 	GtkSourceStyleSchemeManager* manager = gtk_source_style_scheme_manager_get_default();
 	Sourceview* sv;
-	if (!current_style)
-	{
-		current_style = g_strdup (SOURCEVIEW_DEFAULT_STYLE);
-	}
 	sv = sourceview_new(file, filename, plugin);
-	gtk_source_buffer_set_style_scheme (GTK_SOURCE_BUFFER (sv->priv->document),
-										gtk_source_style_scheme_manager_get_scheme (manager,
-																					current_style));
+	if (current_style)
+		gtk_source_buffer_set_style_scheme (GTK_SOURCE_BUFFER (sv->priv->document),
+											gtk_source_style_scheme_manager_get_scheme (manager,
+																						current_style));
 	g_free (current_style);
 	return IANJUTA_EDITOR (sv);
 }
@@ -154,10 +150,7 @@ create_style_model (AnjutaPreferences* prefs, GtkTreeIter** current)
 	const gchar* const *styles = gtk_source_style_scheme_manager_get_scheme_ids (manager);
 	const gchar* const *style;
 	gchar* current_style = anjuta_preferences_get (prefs, SOURCEVIEW_STYLE);
-	if (!current_style)
-	{
-		current_style = g_strdup (SOURCEVIEW_DEFAULT_STYLE);
-	}
+	*current = NULL;
 	for (style = styles; *style != NULL; style++)
 	{
 		GtkTreeIter iter;
@@ -169,7 +162,7 @@ create_style_model (AnjutaPreferences* prefs, GtkTreeIter** current)
 							COLUMN_NAME, gtk_source_style_scheme_get_name (scheme),
 							COLUMN_DESC, gtk_source_style_scheme_get_description (scheme),
 							COLUMN_ID, id, -1);
-		if (g_str_equal (id, current_style))
+		if (current_style && g_str_equal (id, current_style))
 		{
 			*current = gtk_tree_iter_copy (&iter);
 		}
