@@ -114,7 +114,7 @@ create_columns (LogData *data)
 	column = gtk_tree_view_column_new ();
 	renderer = gtk_cell_renderer_toggle_new ();
 	gtk_tree_view_column_pack_start (column, renderer, TRUE);
-	gtk_tree_view_column_set_title (column, "Diff");
+	gtk_tree_view_column_set_title (column, _("Diff"));
 	gtk_tree_view_append_column (GTK_TREE_VIEW (log_changes_view), column);
 	gtk_tree_view_column_add_attribute (column, renderer, "active", 
 										COL_DIFF_SELECTED);
@@ -127,7 +127,7 @@ create_columns (LogData *data)
 	column = gtk_tree_view_column_new ();
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start (column, renderer, TRUE);
-	gtk_tree_view_column_set_title (column, "Author");
+	gtk_tree_view_column_set_title (column, _("Author"));
 	gtk_tree_view_append_column (GTK_TREE_VIEW (log_changes_view), column);
 	gtk_tree_view_column_add_attribute (column, renderer, "text", 
 										COL_AUTHOR);
@@ -136,7 +136,7 @@ create_columns (LogData *data)
 	column = gtk_tree_view_column_new ();
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start (column, renderer, TRUE);
-	gtk_tree_view_column_set_title (column, "Date");
+	gtk_tree_view_column_set_title (column, _("Date"));
 	gtk_tree_view_append_column (GTK_TREE_VIEW (log_changes_view), column);
 	gtk_tree_view_column_add_attribute (column, renderer, "text", 
 										COL_DATE);
@@ -146,7 +146,7 @@ create_columns (LogData *data)
 	column = gtk_tree_view_column_new ();
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start (column, renderer, TRUE);
-	gtk_tree_view_column_set_title (column, "Revision");
+	gtk_tree_view_column_set_title (column, _("Revision"));
 	gtk_tree_view_append_column (GTK_TREE_VIEW (log_changes_view), column);
 	gtk_tree_view_column_add_attribute (column, renderer, "text", 
 										COL_REVISION);
@@ -155,7 +155,7 @@ create_columns (LogData *data)
 	column = gtk_tree_view_column_new ();
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start (column, renderer, TRUE);
-	gtk_tree_view_column_set_title (column, "Short Log");
+	gtk_tree_view_column_set_title (column, _("Short Log"));
 	gtk_tree_view_append_column (GTK_TREE_VIEW (log_changes_view), column);
 	gtk_tree_view_column_add_attribute (column, renderer, "text", 
 										COL_SHORT_LOG);
@@ -220,7 +220,7 @@ on_log_command_finished (AnjutaCommand *command, guint return_code,
 }
 
 static void
-on_log_view_button_clicked (GtkButton *button, LogData *data)
+subversion_show_log (LogData *data)
 {
 	GtkWidget *log_changes_view;
 	GtkWidget *log_file_entry;
@@ -273,6 +273,12 @@ on_log_view_button_clicked (GtkButton *button, LogData *data)
 	gtk_list_store_clear (data->log_store);
 }
 
+static void
+on_log_view_button_clicked (GtkButton *button, LogData *data)
+{
+	subversion_show_log (data);
+}
+
 static void
 on_cat_command_data_arrived (AnjutaCommand *command, IAnjutaEditor *editor)
 {
@@ -399,6 +405,7 @@ on_log_diff_selected_button_clicked (GtkButton *button, LogData *data)
 		diff_command = svn_diff_command_new (data->path, 
 											 revision1,
 											 revision2,
+											 data->plugin->project_root_dir,
 											 TRUE);
 		
 		docman = anjuta_shell_get_interface (ANJUTA_PLUGIN (data->plugin)->shell,
@@ -463,8 +470,11 @@ on_log_diff_previous_button_clicked (GtkButton *button, LogData *data)
 						COL_REVISION, &revision,
 						-1);
 	
-	diff_command = svn_diff_command_new (data->path, SVN_DIFF_REVISION_PREVIOUS,
-										 revision, TRUE); 
+	diff_command = svn_diff_command_new (data->path,
+										 SVN_DIFF_REVISION_PREVIOUS,
+										 revision,
+										 data->plugin->project_root_dir,
+										 TRUE);
 	
 	docman = anjuta_shell_get_interface (ANJUTA_PLUGIN (data->plugin)->shell,
 	                                     IAnjutaDocumentManager, NULL);
@@ -602,6 +612,7 @@ subversion_log_window_create (Subversion *plugin)
 	
 	g_object_set_data (G_OBJECT (log_whole_project_check), "fileentry",
 					   log_file_entry);
+	g_object_set_data (G_OBJECT (subversion_log_vbox), "log-data", data);
 	g_signal_connect (G_OBJECT (log_whole_project_check), "toggled",
 					  G_CALLBACK (on_whole_project_toggled), plugin);
 	init_whole_project (plugin, log_whole_project_check, FALSE);
@@ -647,14 +658,22 @@ void
 on_fm_subversion_log (GtkAction *action, Subversion *plugin)
 {
 	GtkWidget *log_file_entry;
+	GtkWidget *log_whole_project_check;
 	
 	log_file_entry = glade_xml_get_widget (plugin->log_gxml, "log_file_entry");
+	log_whole_project_check = glade_xml_get_widget (plugin->log_gxml,
+													"log_whole_project_check");
 	
 	gtk_entry_set_text (GTK_ENTRY (log_file_entry), 
 						plugin->fm_current_filename);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (log_whole_project_check),
+								  FALSE);
 	
 	anjuta_shell_present_widget (ANJUTA_PLUGIN (plugin)->shell, 
 								 plugin->log_viewer, NULL);
+	
+	subversion_show_log (g_object_get_data (G_OBJECT (plugin->log_viewer), 
+											"log-data"));
 }
 
 void
